==> wildfly-ee-dist-23.0.0.Final-src.zip: wildfly-23.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/jca/statistics/xa/SLSB1.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright (c) 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.jca.statistics.xa;

import javax.annotation.Resource;
import javax.ejb.Stateless;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.transaction.TransactionManager;
import javax.transaction.UserTransaction;

import org.jboss.as.test.integration.transactions.TransactionCheckerSingleton;
import org.jboss.as.test.integration.transactions.TxTestUtil;

/**
 * @author dsimko@redhat.com
 */
@Stateless
@TransactionManagement(TransactionManagementType.BEAN)
public class SLSB1 implements SLSB {

    @PersistenceContext(unitName = "testxapu")
    private EntityManager em;

    @Resource(name = "java:jboss/TransactionManager")
    private TransactionManager tm;

    @Resource
    private UserTransaction tx;

    @Inject
    private TransactionCheckerSingleton checker;

    @Override
    public void commit() throws Exception {
        tx.begin();
        TxTestUtil.enlistTestXAResource(tm.getTransaction(), checker);
        em.persist(new TestEntity());
        tx.commit();
    }

    @Override
    public void rollback() throws Exception {
        tx.begin();
        TxTestUtil.enlistTestXAResource(tm.getTransaction(), checker);
        em.persist(new TestEntity());
        tx.rollback();
    }

}

==> wildfly-ee-dist-27.0.0.Final-src.zip: wildfly-27.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/jca/statistics/xa/SLSB1.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright (c) 2016, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.jca.statistics.xa;

import jakarta.annotation.Resource;
import jakarta.ejb.Stateless;
import jakarta.ejb.TransactionManagement;
import jakarta.ejb.TransactionManagementType;
import jakarta.inject.Inject;
import jakarta.persistence.EntityManager;
import jakarta.persistence.PersistenceContext;
import jakarta.transaction.TransactionManager;
import jakarta.transaction.UserTransaction;

import org.jboss.as.test.integration.transactions.TransactionCheckerSingleton;
import org.jboss.as.test.integration.transactions.TxTestUtil;

/**
 * @author dsimko@redhat.com
 */
@Stateless
@TransactionManagement(TransactionManagementType.BEAN)
public class SLSB1 implements SLSB {

    @PersistenceContext(unitName = "testxapu")
    private EntityManager em;



    @Resource(name = "java:jboss/TransactionManager")
    private TransactionManager tm;

    @Resource
    private UserTransaction tx;

    @Inject
    private TransactionCheckerSingleton checker;

    @Override
    public void commit() throws Exception {
        tx.begin();
        TxTestUtil.enlistTestXAResource(tm.getTransaction(), checker);
        em.persist(new TestEntity());
        tx.commit();
    }

    @Override
    public void rollback() throws Exception {

        tx.begin();
        TxTestUtil.enlistTestXAResource(tm.getTransaction(), checker);

        em.persist(new TestEntity());
        em.flush();
        tx.rollback();
    }

}
